//
//  TestController.swift
//  SampleApp
//
//  Created by Nishan Niraula on 10/15/20.
//  Copyright © 2020 David Zhang. All rights reserved.
//

import Foundation
import UIKit
import AmitySDK
import Combine
import SwiftUI

// NOTE:
// Ignore stuffs in this class. This class is just for quick testing of sdk stuffs inside sample app.
class TestController: UIViewController {
    let buttonStack = UIStackView(frame: .zero)
    
    let client = AmityManager.shared.client!
    
    var token: AmityNotificationToken?
    
    let userRepo = AmityUserRepository(client: AmityManager.shared.client!)
    let commRepo = AmityCommunityRepository(client: AmityManager.shared.client!)
    let commentRepo = AmityCommentRepository(client: AmityManager.shared.client!)
    let postRepo = AmityPostRepository(client: AmityManager.shared.client!)
    let channelRepo = AmityChannelRepository(client: AmityManager.shared.client!)
    let messageRepo = AmityMessageRepository(client: AmityManager.shared.client!)
    let fileRepo = AmityFileRepository(client: AmityManager.shared.client!)
    let subChannelRepo = AmitySubChannelRepository(client: AmityManager.shared.client!)
    let reactionRepo = AmityReactionRepository(client: AmityManager.shared.client!)
    let userPresenceRepo = AmityUserPresenceRepository(client: AmityManager.shared.client!)
    let channelPresenceRepo = AmityChannelPresenceRepository(client: AmityManager.shared.client!)
    
    var disposeBag: Set<AnyCancellable> = []
    
    var label = UILabel()
        
    override func loadView() {
        view = UIView()
        view.backgroundColor = .white
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        AmityLog.logLevel = .all        
        
        setupViews()
    }
    
    @objc func onButton1Tap() {
        
    }
    
    // 65559299d12abd0b39190a2d
    
    @objc func onButton2Tap() { // 6554538d93e1782c7a1d336d
        for i in 0..<3 {
            DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
                let options = AmityTextMessageCreateOptions(subChannelId: "65559e0b15517359ba411dd9", text: "Testing message queue \(Int.random(in: 0...100))-\(i)")
                self.messageRepo.createTextMessage(options: options) { message, error in
                    
                    guard let message else { return }
                    print("[Sync] Message Created! Error: \(error?.localizedDescription ?? "-")")

                }
            }
        }
    }
        
    @MainActor
    @objc func onButton3Tap() {
        let query = AmityMessageQueryOptions(subChannelId: "65559e0b15517359ba411dd9")
        token = messageRepo.getMessages(options: query).observe { liveCollection, _, error in
            
            let allObjects = liveCollection.allObjects()
            for object in allObjects {
                print("[Subchannel] Message: \(object.data?["text"] as? String ?? ""), Sync State: \(object.syncState.description)")
            }
        }
    }
    
    @objc func onButton4Tap() {
    }
        
    func setupViews() {
        
        let button1 = UIBarButtonItem(title: "A1", style: .plain, target: self, action: #selector(onButton1Tap))
        let button2 = UIBarButtonItem(title: "A2", style: .plain, target: self, action: #selector(onButton2Tap))
        let button3 = UIBarButtonItem(title: "A3", style: .plain, target: self, action: #selector(onButton3Tap))
        let button4 = UIBarButtonItem(title: "A4", style: .plain, target: self, action: #selector(onButton4Tap))
        
        self.navigationItem.rightBarButtonItems = [button1, button2, button3, button4]
    }
}
